@@ -13,7 +13,11 @@
 #' @param cardinal Defines the value of y considered extreme (\emph{default} considers 0 germination)
 #' @param scale Sets x scale (\emph{default} is none, can be "log")
 #' @param width.bar bar width
-#' @return The function returns the coefficients and respective p-values; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean squared error); cardinal and optimal temperatures and the graph using ggplot2 with the equation.
+#' @param textsize Font size
+#' @param pointsize shape size
+#' @param linesize line size
+#' @param pointshape format point (\emph{default} is 21)
+#' @param font.family Font family (\emph{default} is sans)
 #' @details The model function for the Brain-Cousens model (Brain and Cousens, 1989) is
 #' \deqn{ f(x, b,c,d,e,f) = c + \frac{d-c+fx}{1+\exp(b(\log(x)-\log(e)))}}
 #' and it is a five-parameter model, obtained by extending the four-parameter log-logistic model (LL.4 to take into account inverse u-shaped hormesis effects.
@@ -21,6 +25,21 @@
 #' \deqn{f(x) = 0 + \frac{d-0+fx}{1+\exp(b(\log(x)-\log(e)))}}
 #' used by van Ewijk and Hoekstra (1993).
 #' @note if the maximum predicted value is equal to the maximum x, the curve does not have a maximum point within the studied range. If the minimum value is less than the lowest point studied, disregard the value.
+#' @return
+#'   \describe{
+#'   \item{\code{Coefficients}}{Coefficients and their p values}
+#'   \item{\code{Optimum temperature}}{Optimum temperature (equivalent to the maximum point)}
+#'   \item{\code{Optimum temperature response}}{Response at the optimal temperature (equivalent to the maximum point)}
+#'   \item{\code{Minimal temperature}}{Temperature that has the lowest response}
+#'   \item{\code{Minimal temperature response}}{Lowest predicted response}
+#'   \item{\code{Predicted maximum basal value}}{Lower basal limit temperature based on the value set by the user (default is 0)}
+#'   \item{\code{Predicted minimum basal value}}{Upper basal limit temperature based on the value set by the user (default is 0)}
+#'   \item{\code{AIC}}{Akaike information criterion}
+#'   \item{\code{BIC}}{Bayesian Inference Criterion}
+#'   \item{\code{r-squared}}{Determination coefficient}
+#'   \item{\code{RMSE}}{Root mean square error}
+#'   \item{\code{grafico}}{Graph in ggplot2 with equation}
+#'   }
 #' @export
 #' @import ggplot2
 #' @import drc
@@ -69,7 +88,12 @@ BC_model=function(trat,
                   cardinal=0,
                   r2="all",
                   width.bar=NA,
-                  scale="none"){
+                  scale="none",
+                  textsize=12,
+                  pointsize=4.5,
+                  linesize=0.8,
+                  pointshape=21,
+                  font.family="sans"){
   requireNamespace("ggplot2")
   requireNamespace("drc")
   requireNamespace("crayon")
@@ -134,16 +158,17 @@ BC_model=function(trat,
   graph=ggplot(data,aes(x=xmean,y=ymean))
   if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,
                                                    ymax=ymean+ysd),
-                                               width=width.bar,size=0.8)}
-  graph=graph+geom_point(aes(color="black"),size=4.5,pch=21,fill="gray")+
+                                               width=width.bar,size=linesize)}
+  graph=graph+geom_point(aes(color="black"),size=pointsize,pch=pointshape,fill="gray")+
     theme+
     geom_line(data=preditos,aes(x=x,
                                 y=y,
-                                color="black"),size=0.8)+
+                                color="black"),size=linesize)+
     scale_color_manual(name="",values=1,label=parse(text = equation))+
-    theme(axis.text = element_text(size=12,color="black"),
+    theme(axis.text = element_text(size=textsize,color="black",family = font.family),
           legend.position = legend.position,
-          legend.text = element_text(size=12),
+          legend.text = element_text(size=textsize,family = font.family),
+          axis.title = element_text(family = font.family),
           legend.direction = "vertical",
           legend.text.align = 0,
           legend.justification = 0)+
@@ -154,6 +179,9 @@ BC_model=function(trat,
                  type="response")
   maximo=temp1[which.max(result)]
   respmax=result[which.max(result)]
+  mini=temp1[which.min(result)]
+  respmin=result[which.min(result)]
+
   result1=round(result,0)
   fa=temp1[result1<=cardinal & temp1>maximo]
   if(length(fa)>0){maxl=max(temp1[result1<=cardinal & temp1>maximo])}else{
@@ -163,23 +191,30 @@ BC_model=function(trat,
     minimo=NA}
   aic=AIC(mod)
   bic=BIC(mod)
-  graphs=data.frame("Parameter"=c("optimum temperature",
-                                  "Maximum response",
-                                  "Predicted maximum value",
-                                  "Predicted minimum value",
+  graphs=data.frame("Parameter"=c("Optimum temperature",
+                                  "Optimum temperature response",
+                                  "Minimal temperature",
+                                  "Minimal temperature response",
+                                  "Predicted maximum basal value",
+                                  "Predicted minimum basal value",
                                   "AIC",
                                   "BIC",
                                   "r-squared",
                                   "RMSE"),
-                    "values"=c(maximo,
+                    "values"=round(c(maximo,
                                respmax,
+                               mini,
+                               respmin,
                                maxl,
                                minimo,
                                aic,
                                bic,
                                r2,
-                               rmse))
-  graficos=list("Coefficients"=coef,
+                               rmse),7))
+  models=data.frame(coef$coefficients)
+  models$Sig=ifelse(models$p.value>0.05,"ns",ifelse(models$p.value<0.01,"**","*"))
+  colnames(models)=c("Estimate","Std Error","t value","P-value","")
+  graficos=list("Coefficients"=models,
                 "values"=graphs,
                 graph)
   print(graficos)
